@@ -4,13 +4,9 @@ and core metadata
 """
 
 import re
-from pathlib import Path
-from typing import Union
 
 import packaging
 
-_Path = Union[str, Path]
-
 # https://packaging.python.org/en/latest/specifications/core-metadata/#name
 _VALID_NAME = re.compile(r"^([A-Z0-9]|[A-Z0-9][A-Z0-9._-]*[A-Z0-9])$", re.I)
 _UNSAFE_NAME_CHARS = re.compile(r"[^A-Z0-9._-]+", re.I)
@@ -138,7 +134,13 @@ def filename_component_broken(value: str) -> str:
 def safer_name(value: str) -> str:
     """Like ``safe_name`` but can be used as filename component for wheel"""
     # See bdist_wheel.safer_name
-    return filename_component(safe_name(value))
+    return (
+        # Per https://packaging.python.org/en/latest/specifications/name-normalization/#name-normalization
+        re.sub(r"[-_.]+", "-", safe_name(value))
+        .lower()
+        # Per https://packaging.python.org/en/latest/specifications/binary-distribution-format/#escaping-and-unicode
+        .replace("-", "_")
+    )
 
 
 def safer_best_effort_version(value: str) -> str:
