@@ -1,11 +1,11 @@
 from __future__ import annotations
 
-import sys
 import ast
-import os
 import glob
+import os
 import re
 import stat
+import sys
 import time
 from pathlib import Path
 from unittest import mock
@@ -14,16 +14,11 @@ import pytest
 from jaraco import path
 
 from setuptools import errors
-from setuptools.command.egg_info import (
-    egg_info,
-    manifest_maker,
-    write_entries,
-)
+from setuptools.command.egg_info import egg_info, manifest_maker, write_entries
 from setuptools.dist import Distribution
 
-from . import environment
+from . import contexts, environment
 from .textwrap import DALS
-from . import contexts
 
 
 class Environment(str):
@@ -43,9 +38,8 @@ def env():
                 '.pydistutils.cfg': DALS(
                     """
                 [egg_info]
-                egg-base = %(egg-base)s
-                """
-                    % env.paths
+                egg-base = {egg-base}
+                """.format(**env.paths)
                 )
             }
         })
@@ -265,13 +259,9 @@ class TestEggInfo:
             'setup.cfg': setup_config,
         })
 
-    mismatch_marker = "python_version<'{this_ver}'".format(
-        this_ver=sys.version_info[0],
-    )
+    mismatch_marker = f"python_version<'{sys.version_info[0]}'"
     # Alternate equivalent syntax.
-    mismatch_marker_alternate = 'python_version < "{this_ver}"'.format(
-        this_ver=sys.version_info[0],
-    )
+    mismatch_marker_alternate = f'python_version < "{sys.version_info[0]}"'
     invalid_marker = "<=>++"
 
     class RequiresTestHelper:
@@ -288,9 +278,9 @@ class TestEggInfo:
                 else:
                     install_cmd_kwargs = {}
                 name = name_kwargs[0].strip()
-                setup_py_requires, setup_cfg_requires, expected_requires = (
+                setup_py_requires, setup_cfg_requires, expected_requires = [
                     DALS(a).format(**format_dict) for a in test_params
-                )
+                ]
                 for id_, requires, use_cfg in (
                     (name, setup_py_requires, False),
                     (name + '_in_setup_cfg', setup_cfg_requires, True),
@@ -310,7 +300,12 @@ class TestEggInfo:
                         )
                     )
             return pytest.mark.parametrize(
-                'requires,use_setup_cfg,expected_requires,install_cmd_kwargs',
+                (
+                    "requires",
+                    "use_setup_cfg",
+                    "expected_requires",
+                    "install_cmd_kwargs",
+                ),
                 argvalues,
                 ids=idlist,
             )
@@ -517,7 +512,7 @@ class TestEggInfo:
         environ = os.environ.copy().update(
             HOME=env.paths['home'],
         )
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -527,7 +522,7 @@ class TestEggInfo:
         with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
             pkg_info_lines = fp.read().split('\n')
         assert 'Provides-Extra: foobar' in pkg_info_lines
-        assert 'Metadata-Version: 2.1' in pkg_info_lines
+        assert 'Metadata-Version: 2.2' in pkg_info_lines
 
     def test_doesnt_provides_extra(self, tmpdir_cwd, env):
         self._setup_script_with_requires(
@@ -548,7 +543,7 @@ class TestEggInfo:
         assert 'Provides-Extra:' not in pkg_info_text
 
     @pytest.mark.parametrize(
-        "files, license_in_sources",
+        ('files', 'license_in_sources'),
         [
             (
                 {
@@ -632,7 +627,7 @@ class TestEggInfo:
             assert 'INVALID_LICENSE' not in sources_text
 
     @pytest.mark.parametrize(
-        "files, incl_licenses, excl_licenses",
+        ('files', 'incl_licenses', 'excl_licenses'),
         [
             (
                 {
@@ -844,7 +839,7 @@ class TestEggInfo:
             assert sources_lines.count(lf) == 0
 
     @pytest.mark.parametrize(
-        "files, incl_licenses, excl_licenses",
+        ('files', 'incl_licenses', 'excl_licenses'),
         [
             (
                 {
@@ -1065,7 +1060,7 @@ class TestEggInfo:
     def test_metadata_version(self, tmpdir_cwd, env):
         """Make sure latest metadata version is used by default."""
         self._setup_script_with_requires("")
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -1074,7 +1069,7 @@ class TestEggInfo:
         with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
             pkg_info_lines = fp.read().split('\n')
         # Update metadata version if changed
-        assert self._extract_mv_version(pkg_info_lines) == (2, 1)
+        assert self._extract_mv_version(pkg_info_lines) == (2, 2)
 
     def test_long_description_content_type(self, tmpdir_cwd, env):
         # Test that specifying a `long_description_content_type` keyword arg to
@@ -1090,7 +1085,7 @@ class TestEggInfo:
         environ = os.environ.copy().update(
             HOME=env.paths['home'],
         )
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -1101,7 +1096,7 @@ class TestEggInfo:
             pkg_info_lines = fp.read().split('\n')
         expected_line = 'Description-Content-Type: text/markdown'
         assert expected_line in pkg_info_lines
-        assert 'Metadata-Version: 2.1' in pkg_info_lines
+        assert 'Metadata-Version: 2.2' in pkg_info_lines
 
     def test_long_description(self, tmpdir_cwd, env):
         # Test that specifying `long_description` and `long_description_content_type`
@@ -1112,7 +1107,7 @@ class TestEggInfo:
             "long_description='This is a long description\\nover multiple lines',"
             "long_description_content_type='text/markdown',"
         )
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -1120,7 +1115,7 @@ class TestEggInfo:
         egg_info_dir = os.path.join('.', 'foo.egg-info')
         with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
             pkg_info_lines = fp.read().split('\n')
-        assert 'Metadata-Version: 2.1' in pkg_info_lines
+        assert 'Metadata-Version: 2.2' in pkg_info_lines
         assert '' == pkg_info_lines[-1]  # last line should be empty
         long_desc_lines = pkg_info_lines[pkg_info_lines.index('') :]
         assert 'This is a long description' in long_desc_lines
@@ -1143,7 +1138,7 @@ class TestEggInfo:
         environ = os.environ.copy().update(
             HOME=env.paths['home'],
         )
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -1161,7 +1156,7 @@ class TestEggInfo:
     def test_license(self, tmpdir_cwd, env):
         """Test single line license."""
         self._setup_script_with_requires("license='MIT',")
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -1176,7 +1171,7 @@ class TestEggInfo:
         self._setup_script_with_requires(
             "license='This is a long license text \\nover multiple lines',"
         )
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
@@ -1194,7 +1189,7 @@ class TestEggInfo:
         environ = os.environ.copy().update(
             HOME=env.paths['home'],
         )
-        code, data = environment.run_setup_py(
+        environment.run_setup_py(
             cmd=['egg_info'],
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
             data_stream=1,
